<?php
/**
 * @file
 * Admin settings file.
 */

/**
 * Open Flash Chart 2 API settings form.
 */
function open_flash_chart_api_admin_settings() {

  $form['open_flash_chart_api_library_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to Open Flash Chart v2'),
    '#default_value' => variable_get('open_flash_chart_api_library_path', 'sites/all/libraries/ofcv2'),
    '#size' => 55,
    '#maxlength' => 255,
    '#description' => t('This is the ofc library root directory.  It should contain both /open-flash-chart.swf and /js/swfobject.js and should be a path relative to the drupal install directory.'),
  );

  $form['open_flash_chart_api_use_swfobject'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('open_flash_chart_api_use_swfobject', TRUE),
    '#title' => t('Use SWFObject to embed charts'),
    '#description' => t('If enabled, Open Flash Chart 2 API will use !swfobject to embed charts into the page. Note that this only works if the end-user has JavaScript enabled in their browser.', array('!swfobject' => l('SWFObject', 'http://code.google.com/p/swfobject'))),
  );

  $form['open_flash_chart_api_wmode_transparent'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('open_flash_chart_api_wmode_transparent', FALSE),
    '#title' => t('Use wmode:transparent for all charts'),
    '#description' => t('If enabled, Open Flash Chart 2 API will apply !wmode-transparent to all charts. This helps resolve the issue about Flash content always stays on top which can make some element like CSS drop-down menu inaccessible. Alternatively, you can specify this parameter for individual chart when calling !render-function.', array('!wmode-transparent' => '<span style="font-family:monospace">' . check_plain('<param name="wmode" value="transparent" />') . '</span>', '!render-function' => '<span style="font-family:monospace">' . check_plain('open_flash_chart_api_render()') . '</span>')),
  );

  $form['open_flash_chart_api_library_container'] = array(
    '#title' => t('External library'),
    '#type' => 'fieldset',
    '#description' => t('You can use an external library instead of the built-in one. So you can create chart objects the way you want.'),
    '#collapsible' => FALSE,
    '#collapsed' => !variable_get('open_flash_chart_api_use_library', FALSE),
  );

  $form['open_flash_chart_api_library_container']['open_flash_chart_api_use_library'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('open_flash_chart_api_use_library', FALSE),
    '#title' => t('Use external library'),
    '#description' => t("If checked, Open Flash Chart 2 API will include the specified library file and enable you to use the library's functions to create the chart object."),
  );

  $form['open_flash_chart_api_library_container']['open_flash_chart_api_library'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to external library file'),
    '#default_value' => variable_get('open_flash_chart_api_library', 'php5-ofc-library/open-flash-chart-object.php'),
    '#description' => t('The path to the main external library file, relative to the ofc_libroot.  Example: php5-ofc-library/open-flash-chart-object.php'),
  );

  return system_settings_form($form);
}

/**
 * Settings form validation
 */
function open_flash_chart_api_admin_settings_validate($form, $form_state) {

  // Test for finding the library files.
  if (!file_exists($form_state['values']['open_flash_chart_api_library_path'] . '/open-flash-chart.swf')) {
    form_set_error('open_flash_chart_api_library_path', t('Could not find open-flash-chart.swf in the libroot.'));
  }

  // If use swfobject is checked, make sure it exists.
  if ($form_state['values']['open_flash_chart_api_use_swfobject'] == TRUE) {
    if (!file_exists($form_state['values']['open_flash_chart_api_library_path'] . '/js/swfobject.js')) {
      form_set_error('open_flash_chart_api_library_path', t('Could not find swfobject.js in the libroot/js directory.'));
    }
  }

  // If open_flash_chart_api_use_library is checked, make sure it exists.
  if ($form_state['values']['open_flash_chart_api_use_library']) {
    if (!file_exists($form_state['values']['open_flash_chart_api_library_path'] . '/' . $form_state['values']['open_flash_chart_api_library'])) {
      form_set_error('open_flash_chart_api_library', t('Could not find the external library file.'));
    }
  }
}